(* Content-type: application/vnd.wolfram.mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 13.2' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       158,          7]
NotebookDataLength[      9093,        221]
NotebookOptionsPosition[      8345,        199]
NotebookOutlinePosition[      8789,        216]
CellTagsIndexPosition[      8746,        213]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{

Cell[CellGroupData[{
Cell[TextData[{
 StyleBox["Mathematica code to simulate the Galton board\n",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 0]],
 StyleBox["Leonardo Dagdug,  Ivan Pompa-Garc\[IAcute]a,  Jason Pe\[NTilde]a",
  FontSize->14,
  FontColor->RGBColor[1, 0, 0]],
 StyleBox["\n",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 0]],
 StyleBox["From the book:\n ",
  FontSize->18,
  FontColor->RGBColor[1, 0, 0]],
 StyleBox["Diffusion Under Confinement: A Journey Through Counterintuition",
  FontSize->18,
  FontSlant->"Italic",
  FontColor->RGBColor[1, 0, 0]]
}], "Subtitle",
 CellChangeTimes->{{3.897401317577585*^9, 3.8974013660192966`*^9}, {
   3.8974868042908697`*^9, 3.897486811354224*^9}, {3.897516572581173*^9, 
   3.897516575588283*^9}, {3.8975166187500067`*^9, 3.897516707916236*^9}, 
   3.897516818075986*^9, {3.900499562260807*^9, 3.9004995911624193`*^9}, {
   3.900674744451146*^9, 3.900674757510326*^9}},
 TextAlignment->Center,ExpressionUUID->"ae6e2f6c-7fb8-492b-9a0e-84a5b2bf623f"],

Cell[TextData[StyleBox["The Galton board simulation",
 FontSize->18,
 FontWeight->"Bold",
 FontColor->RGBColor[0, 0, 1]]], "Text",
 CellChangeTimes->{{3.897401460848901*^9, 3.897401476999867*^9}, {
  3.8974025225957117`*^9, 3.897402523315486*^9}, {3.900499617379546*^9, 
  3.900499622403261*^9}, {3.900499853171557*^9, 
  3.900499858618123*^9}},ExpressionUUID->"51837b9d-c5f1-43b2-8e52-\
a11d64bdf05c"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"Galtonboard", "[", 
   RowBox[{"(*", 
    RowBox[{"number", " ", "of", " ", "pegs"}], "*)"}], 
   RowBox[{"pegs_", ",", " ", 
    RowBox[{"(*", 
     RowBox[{"number", " ", "of", " ", "balls"}], "*)"}], "balls_"}], "]"}], ":=",
   "\n", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"(*", 
      RowBox[{"Definition", " ", "of", " ", "local", " ", "variables"}], 
      "*)"}], 
     RowBox[{"position", ",", " ", "list", ",", " ", "motionofparticle"}], 
     "}"}], ",", "\n", 
    RowBox[{"(*", 
     RowBox[{
     "We", " ", "make", " ", "a", " ", "table", " ", "containing", " ", 
      "every", " ", "final", " ", "output", " ", "of", " ", "the", " ", 
      "simulation"}], "*)"}], "\n", 
    RowBox[{
     RowBox[{"list", "=", 
      RowBox[{"Table", "[", "\n", "\t", 
       RowBox[{"(*", 
        RowBox[{
        "definition", " ", "of", " ", "the", " ", "initial", " ", "position", 
         " ", "of", " ", "each", " ", "ball", " ", "at", " ", "the", " ", 
         "top", " ", "the", " ", "board"}], "*)"}], "\n", 
       RowBox[{
        RowBox[{
         RowBox[{"position", "=", " ", 
          RowBox[{"(*", 
           RowBox[{
           "intial", " ", "position", " ", "randomly", " ", "chosen"}], 
           "*)"}], " ", 
          RowBox[{"IntegerPart", "[", 
           RowBox[{"pegs", "/", "2"}], "]"}]}], ";", "\n", "\t", 
         RowBox[{"(*", 
          RowBox[{
          "evaluation", " ", "of", " ", "the", " ", "position", " ", "after", 
           " ", "colliding", " ", "with", " ", "every", " ", "peg"}], "*)"}], 
         "\n", 
         RowBox[{"Do", "[", "\[IndentingNewLine]", "\t", 
          RowBox[{"(*", 
           RowBox[{
           "equal", " ", "probability", " ", "of", " ", "moving", " ", "to", 
            " ", "the", " ", "left", " ", "of", " ", "the", " ", "right"}], 
           "*)"}], "\n", 
          RowBox[{
           RowBox[{
            RowBox[{"motionofparticle", "=", 
             RowBox[{"RandomChoice", "[", 
              RowBox[{"{", 
               RowBox[{
                RowBox[{"-", "1"}], ",", "1"}], "}"}], "]"}]}], ";", "\n", 
            RowBox[{"position", " ", "=", " ", 
             RowBox[{"position", " ", "+", " ", "motionofparticle"}]}], ";"}],
            "\n", ",", "pegs"}], "]"}], ";", "\n", "position"}], ",", 
        RowBox[{"{", "balls", "}"}]}], "]"}]}], ";", "\n", 
     RowBox[{"Histogram", "[", 
      RowBox[{"list", ",", 
       RowBox[{"{", "1", "}"}], ",", 
       RowBox[{"Background", "->", "White"}], ",", " ", 
       RowBox[{"Frame", "->", "True"}]}], "]"}]}]}], "\n", "]"}]}], "\n", 
 RowBox[{"Galtonboard", "[", 
  RowBox[{"100", ",", "10000"}], "]"}]}], "Input",
 CellChangeTimes->{{3.900499871200988*^9, 3.9004998986346273`*^9}, {
  3.9004999362026777`*^9, 3.90049993645542*^9}},
 CellLabel->"In[3]:=",ExpressionUUID->"816728dd-e320-4fdb-bf8e-6592da19b0ec"],

Cell[BoxData[
 GraphicsBox[{
   {RGBColor[0.987148, 0.8073604000000001, 0.49470040000000004`], EdgeForm[{
    Opacity[0.161], Thickness[Small]}], {}, 
    {RGBColor[0.987148, 0.8073604000000001, 0.49470040000000004`], EdgeForm[{
     Opacity[0.161], Thickness[Small]}], RectangleBox[{14., 0},
      RoundingRadius->0], RectangleBox[{16., 0}, {17., 4.},
      RoundingRadius->0], RectangleBox[{18., 0}, {19., 5.},
      RoundingRadius->0], RectangleBox[{20., 0}, {21., 9.},
      RoundingRadius->0], RectangleBox[{22., 0}, {23., 14.},
      RoundingRadius->0], RectangleBox[{24., 0}, {25., 20.},
      RoundingRadius->0], RectangleBox[{26., 0}, {27., 34.},
      RoundingRadius->0], RectangleBox[{28., 0}, {29., 80.},
      RoundingRadius->0], RectangleBox[{30., 0}, {31., 105.},
      RoundingRadius->0], RectangleBox[{32., 0}, {33., 162.},
      RoundingRadius->0], RectangleBox[{34., 0}, {35., 221.},
      RoundingRadius->0], RectangleBox[{36., 0}, {37., 298.},
      RoundingRadius->0], RectangleBox[{38., 0}, {39., 396.},
      RoundingRadius->0], RectangleBox[{40., 0}, {41., 499.},
      RoundingRadius->0], RectangleBox[{42., 0}, {43., 596.},
      RoundingRadius->0], RectangleBox[{44., 0}, {45., 648.},
      RoundingRadius->0], RectangleBox[{46., 0}, {47., 719.},
      RoundingRadius->0], RectangleBox[{48., 0}, {49., 790.},
      RoundingRadius->0], RectangleBox[{50., 0}, {51., 797.},
      RoundingRadius->0], RectangleBox[{52., 0}, {53., 802.},
      RoundingRadius->0], RectangleBox[{54., 0}, {55., 708.},
      RoundingRadius->0], RectangleBox[{56., 0}, {57., 661.},
      RoundingRadius->0], RectangleBox[{58., 0}, {59., 592.},
      RoundingRadius->0], RectangleBox[{60., 0}, {61., 474.},
      RoundingRadius->0], RectangleBox[{62., 0}, {63., 361.},
      RoundingRadius->0], RectangleBox[{64., 0}, {65., 328.},
      RoundingRadius->0], RectangleBox[{66., 0}, {67., 243.},
      RoundingRadius->0], RectangleBox[{68., 0}, {69., 168.},
      RoundingRadius->0], RectangleBox[{70., 0}, {71., 112.},
      RoundingRadius->0], RectangleBox[{72., 0}, {73., 59.},
      RoundingRadius->0], RectangleBox[{74., 0}, {75., 37.},
      RoundingRadius->0], RectangleBox[{76., 0}, {77., 25.},
      RoundingRadius->0], RectangleBox[{78., 0}, {79., 13.},
      RoundingRadius->0], RectangleBox[{80., 0}, {81., 4.},
      RoundingRadius->0], RectangleBox[{82., 0}, {83., 9.},
      RoundingRadius->0], RectangleBox[{84., 0}, {85., 5.},
      RoundingRadius->0], RectangleBox[{88., 0},
      RoundingRadius->
       0]}, {}, {}}, {{}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, \
{}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, \
{}, {}, {}, {}}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{True, True},
  AxesLabel->{None, None},
  AxesOrigin->{12.5, 0},
  Background->GrayLevel[1],
  Frame->True,
  FrameLabel->{{None, None}, {None, None}},
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  PlotRange->{{14., 89.}, {All, All}},
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {None, 
     Scaled[0.05]}},
  Ticks->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{{3.9004999285179787`*^9, 3.900499937561339*^9}},
 CellLabel->"Out[4]=",ExpressionUUID->"c7724d5a-1361-4b6d-8e92-a43099ac6616"]
}, Open  ]]
}, Open  ]]
},
WindowSize->{1440., 782.25},
WindowMargins->{{3.3301325139235587`, Automatic}, {Automatic, 0}},
Magnification:>1.1 Inherited,
FrontEndVersion->"13.2 for Linux x86 (64-bit) (January 31, 2023)",
StyleDefinitions->"Default.nb",
ExpressionUUID->"fa08be3f-310c-44a5-84f9-d470e622e5eb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[CellGroupData[{
Cell[580, 22, 994, 23, 134, "Subtitle",ExpressionUUID->"ae6e2f6c-7fb8-492b-9a0e-84a5b2bf623f"],
Cell[1577, 47, 402, 8, 42, "Text",ExpressionUUID->"51837b9d-c5f1-43b2-8e52-a11d64bdf05c"],
Cell[CellGroupData[{
Cell[2004, 59, 2930, 70, 448, "Input",ExpressionUUID->"816728dd-e320-4fdb-bf8e-6592da19b0ec"],
Cell[4937, 131, 3380, 64, 263, "Output",ExpressionUUID->"c7724d5a-1361-4b6d-8e92-a43099ac6616"]
}, Open  ]]
}, Open  ]]
}
]
*)

